Diffusion
=========

.. currentmodule:: scarabee

.. autoclass:: scarabee.DiffusionGeometryTile
   :members:

.. autoclass:: scarabee.Neighbor
   :members:

.. autoclass:: scarabee.DiffusionGeometry

.. autoclass:: scarabee.FDDiffusionDriver

.. autoclass:: scarabee.NEMDiffusionDriver
